@@ -22,6 +22,20 @@ class CveXplore(object):
     """
 
     def __init__(self, mongodb_connection_details=None, api_connection_details=None):
+        """
+        Create a new instance of CveXplore
+
+        :param mongodb_connection_details: Provide the connection details needed to establish a connection to a mongodb
+                                           instance. The connection details should be in line with pymongo's
+                                           documentation.
+        :type mongodb_connection_details: dict
+        :param api_connection_details: Provide the connection details needed to establish a connection to a cve-search
+                                       API provider. The cve-search API provider should allow access to the 'query' POST
+                                       endpoint; all other API endpoints are not needed for CveXplore to function. For
+                                       the connection details supported please check the :ref:`API connection <api>`
+                                       documentation.
+        :type api_connection_details: dict
+        """
         self.__version = VERSION
 
         if (
